<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://competition.demo.getfoundni.co.uk
 * @since      1.0.0
 *
 * @package    Gfni_Competition_Lists
 * @subpackage Gfni_Competition_Lists/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gfni_Competition_Lists
 * @subpackage Gfni_Competition_Lists/public
 * @author     Ryan Hull <ryan@getfoundni.co.uk>
 */
class Gfni_Competition_Lists_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gfni_Competition_Lists_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gfni_Competition_Lists_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gfni-competition-lists-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gfni_Competition_Lists_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gfni_Competition_Lists_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gfni-competition-lists-public.js', array( 'jquery' ), $this->version, false );

	} 
 
	public function ticket_page_template($template)
	{
		global $post;
		if($post->post_name == 'competition-ticket-lists'){
			$template = plugin_dir_path(__FILE__) . 'templates/archive_ticket-list.php'; 
		}	
		return $template;
	}

	public function my_plugin_templates( $template ) { 
		$post_types = 'ticket-lists'; 

		if ( is_singular( $post_types ) && file_exists( plugin_dir_path(__FILE__) . 'templates/single_competition-list.php' ) ){
			$template = plugin_dir_path(__FILE__) . 'templates/single_competition-list.php'; 
		}

		return $template;
	}

}
